/* fft.h -- Data type definitions for FFT routines.
*/

/* define one of the below to set data types for FFT input and results. */
/* #define SHORTDATA	/* FC is a short, original data is a byte (8bits)*/
/* #define LONGDATA	/* FC is a long,  original data is a short (16bits) */
#define FLOATDATA	/* FC is a float, original data is a double */

#ifdef SHORTDATA
#define FIXMULT 64	/* Multiplier to convert float to fixed point */
typedef char FFT_DATA;	/* sample input data type */
typedef short  FC;	/* calculation type (twice size of FFT_DATA) */
#endif SHORTDATA

#ifdef LONGDATA
#define FIXMULT 4096	/* Multiplier to convert float to fixed point */
typedef short FFT_DATA;	/* sample input data type */
typedef long  FC;	/* calculation type (twice size of FFT_DATA) */
#endif LONGDATA

#ifdef FLOATDATA
#define FIXMULT 1	/* Multiplier to convert float to float point */
typedef double FFT_DATA;/* sample input data type */
typedef double  FC;	/* calculation type (twice size of FFT_DATA) */
#endif FLOATDATA

/* Complex FFT input and result value */
typedef struct
{
    FC real, imag;
} COMPLEX;

#define PI	3.1419527	/* a handy number */
#define FWD_FFT	1		/* flag to do forward transform */
#define REV_FFT -1		/* flag to do reverse transform */

/* function to build constant table used by fft() */
extern FFT_DATA *sin_arg_table();
