/* pmag.c -- Convert cartesian real/imag arrays into
 *		polar phase/magnitude arrays.
*/
#include <math.h>		/* declare math routines */
#include "fft.h"		/* defines data types for arithmetic */


cart_polar (data)
    	/* Convert a cartesian (x,y) pair into a polar (mag,phase) pair.
	 * The phase portion will be between PI and -PI. */
    COMPLEX *data;
{
	double rdata, idata, temp;

	/* do the arithemetic in floating point,
	 *  cause the math routines support it anyway. */
	 rdata = (double) data->real;
	 idata = (double) data->imag;

	if (rdata == 0.0)
	{
		/* all on the Y axis */
		rdata = fabs (idata);
		idata = (idata < 0.0) ? (-PI / 2.0) : (PI / 2.0) ;
	}
	else if (idata == 0.0)
	{
		/* all on the X axis */
		idata = (rdata < 0.0) ?  PI : 0.0 ;
		rdata = fabs (rdata);
	}
	else
	{
		temp = sqrt ( rdata * rdata + idata * idata);
		idata = atan2 ( idata / rdata );
		rdata = temp;
	}

	data->real = (FC) rdata;
	data->imag = (FC) idata;
}


pmag (data, cnt)
    	/* Convert a COMPLEX cartesian data array into
	 *  a magnitude and phase array.
    COMPLEX *data;	/* input data array */
    int cnt;		/* number of elements in array */
{
	while (--cnt)
	{
		cart_polar (data);
		++data;
	}
}
