/* test.c -- Test routines for FFT program.
*/
#include	<stdio.h>
#include	<math.h>	    /* declare math functions to use */
#include	"fft.h"		    /* FFT data types */


#define STEPS 32			/* number of data points */
#define LOGSTEPS 5			/* log2 of STEPS */

extern double rdata[], idata[];		/* original data in tdata.c */
COMPLEX results[STEPS];			/* FFT input and result array */


main()
{
	FFT_DATA *args;

	/* convert input data to FFT type and copy into COMPLEX array */
	convdata (rdata, idata, results, STEPS);
	pr_carray (results, STEPS);

	/* initialize argument table and externals */
	args = sin_arg_table (STEPS, LOGSTEPS);

	fft (results, FWD_FFT);
	pr_carray (results, STEPS);

/* To reverse transform: */
/* 	fft (results, REV_FFT);
*/ 

/* To print a phase magnitude array: */
	pmag (results, STEPS);
	pr_carray (results, STEPS);

	free (args);
	exit(0);
}


/* multiplier to scale up float data for fixed point */
#ifdef LONGDATA
#define DATAMULT 100
#else
#define DATAMULT 1
#endif

convdata (rdp, idp, comp, size)
	/* Convert and copy the floating point input data arrays to
	 *  the COMPLEX array for the fft() routine. */
    double *rdp;	/* real input */
    double *idp;	/* imag input */
    COMPLEX *comp;	/* converted output array */
    unsigned size;	/* number of elements in arrays */
{
	unsigned cnt;

	for (cnt = 0; cnt != size; ++rdp, ++idp, ++comp, ++cnt )
	{
		comp->real = (FC) (*rdp * DATAMULT);
		comp->imag = (FC) (*idp * DATAMULT);
	}
}


pr_carray (data, size)
	/* print the COMPLEX array elements */
    COMPLEX *data;
    unsigned size;
{
	unsigned cnt;

	printf ("  no.   real	imaginary\n");

	for (cnt = 0; cnt != size; ++data, ++cnt )
	{
#ifdef FLOATDATA
		printf ("%2.2d  %14.8f %14.8f\n", cnt,
			data->real, data->imag);
#endif
#ifdef LONGDATA
		printf ("%2d  %8ld %8ld\n", cnt,
			data->real, data->imag);
#endif
#ifdef SHORTDATA
		printf ("%2d  %4d %4d\n", cnt,
			data->real, data->imag);
#endif
	}
	putchar ('\n');
}
